<?php

/**
 * This file will create admin menu page.
 */

class FCPT_Paywall_Construct
{
    public function __construct()
    {
        add_action('wp_footer', [$this, 'add_paywall_constructor']);
    }

    public function add_paywall_constructor()
    {
        $access_key = get_option('access_key');
        $logo_url =  get_option('logo_url');
        $content_selector = get_option('content_selector');
        $primary_color = get_option('primary_color');
        $monetize_type = get_option('monetize_type');
        $content_preview_height = get_option('content_preview_height');
        $bubble_position = get_option('bubble_position');
        $mobile_offset_vertical = get_option('mobile_offset_vertical');
        $mobile_offset_horizontal = get_option('mobile_offset_horizontal');
        $desktop_offset_vertical = get_option('desktop_offset_vertical');
        $desktop_offset_horizontal = get_option('desktop_offset_horizontal');
        $infinite_scroll = rest_sanitize_boolean(get_option('infinite_scroll'));
        $borderless = rest_sanitize_boolean(get_option('borderless'));
        $function_selector = get_option('function_selector');
        $event_handlers = get_option('event_handlers');
        $should_inject_paywall = get_option('should_inject_paywall');

        $post = get_post();
        $category = get_the_category();
        $article_identifier = $post->ID;

        if ($category) {
            $category_display = '';
            if (class_exists('WPSEO_Primary_Term')) {
                // Show the post's 'Primary' category, if this Yoast feature is available, & one is set 
                $wpseo_primary_term = new WPSEO_Primary_Term('category', get_the_id());
                $wpseo_primary_term = $wpseo_primary_term->get_primary_term();
                $term = get_term($wpseo_primary_term);
                if (is_wp_error($term)) {
                    // Default to first category (not Yoast) if an error is returned
                    $category_display = $category[0]->name;
                } else {
                    // Yoast Primary category
                    $category_display = $term->name;
                }
            } else {
                // Default, display the first category in WP's list of assigned categories
                $category_display = $category[0]->name;
            }
        }

        $paywall_constructor = array();
        $paywall_constructor["contentSelector"] = $content_selector;
        $paywall_constructor["accessKey"] = $access_key;
        $paywall_constructor["primaryColor"] = $primary_color;
        $paywall_constructor["monetizeType"] = $monetize_type;
        $paywall_constructor["category"] = $category_display;
        $paywall_constructor["logoUrl"] = $logo_url;
        $paywall_constructor["articleIdentifier"] = $article_identifier;


        if (!empty($content_preview_height)) {
            $paywall_constructor["contentPreviewHeight"] = intval($content_preview_height);
        }

        if (!empty($bubble_position)) {
            $paywall_constructor["bubblePosition"] = $bubble_position;
        }

        if ($infinite_scroll == true) {
            $paywall_constructor["infiniteScroll"] = true;
        }

        if ($borderless == true) {
            $paywall_constructor["borderless"] = true;
        }

        if (!empty($mobile_offset_vertical) || !empty($mobile_offset_horizontal)) {
            $mobile_offset = array();
            if (!empty($mobile_offset_vertical)) {
                $mobile_offset["vertical"] = $mobile_offset_vertical;
            }
            if (!empty($mobile_offset_horizontal)) {
                $mobile_offset["horizontal"] = $mobile_offset_horizontal;
            }
            $paywall_constructor["mobileOffset"] =  $mobile_offset;
        }

        if (!empty($desktop_offset_vertical) || !empty($desktop_offset_horizontal)) {
            $desktop_offset = array();
            if (!empty($desktop_offset_vertical)) {
                $desktop_offset["vertical"] = $desktop_offset_vertical;
            }
            if (!empty($desktop_offset_horizontal)) {
                $desktop_offset["horizontal"] = $desktop_offset_horizontal;
            }
            $paywall_constructor["desktopOffset"] =  $desktop_offset;
        }

        echo "<script>
        document.addEventListener('DOMContentLoaded', function() {
            ";
        echo "if(!window.Paywall){
                window.__q = { q: [],l: [], v: [], };
                window.Paywall = function () {
                    window.__q.q.push(arguments);
                };
          
                window.Paywall.on = function () {
                    window.__q.l.push(arguments);
                };
          
                window.AudioPaywall = function () {
                    window.__q.v.push(arguments);
                };
          
                window.VideoPaywall = function () {
                    window.__q.v.push(arguments);
                };
            }
            ";

        if (!empty($function_selector)) {
            echo "const functionSelector = $function_selector;
            ";
        } else {
            echo "const functionSelector = null;
            ";
        }

        if (!empty($should_inject_paywall)) {
            echo "const shouldInjectPaywall = $should_inject_paywall
            ";
        } else {
            echo "const shouldInjectPaywall = () => true;
            ";
        }

        $encoded_constructor = str_replace(',"', ',
                "', json_encode($paywall_constructor));
        $encoded_constructor = str_replace('{"', '{
                "', $encoded_constructor);
        $encoded_constructor = str_replace('"}', '"
                }', $encoded_constructor);

        $encoded_constructor = str_replace('},"', '},
    "', $encoded_constructor);
        $encoded_constructor = str_replace('}}', '},
            }', $encoded_constructor);

        echo "const config = $encoded_constructor;
        if(functionSelector){
            config.functionSelector = functionSelector.bind(config);
        }     
        
        if(shouldInjectPaywall()){ 
            Paywall(config);
         }
         ";

        if (!empty($event_handlers)) {
            echo "$event_handlers;";
        }

        if ($infinite_scroll == true) {
            echo "  window.addEventListener('fc_BrowserUrlChanged', (data) => {
                        if( shouldInjectPaywall() ){
                            Paywall(config); ;
                        };
                    })";
        }
        echo "});
        </script>";
    }
}
new FCPT_Paywall_Construct();
