<?php

function fcpt_get_posts()
{
    try {
        $posts = get_posts(["nopaging" => true]); //required to return all articles.
        $data = array();
        $author_name = sanitize_text_field($_REQUEST['author_name']);

        foreach ($posts as $post) {

            $publish_date = new DateTime($post->post_date);
            $category = get_the_category($post->ID);
            $tags = get_the_tags($post->ID);
            $article_identifier = $post->ID;
            $tag_names = "";
            $cat_name = "";
            $regex = '#<p>(.*?)</p>#';
            preg_match($regex, $post->post_content, $matches);
            $post_desc = $matches[0];
            $post_desc = str_replace("</p>", "", $post_desc);
            $post_desc = str_replace("<p>", "", $post_desc);

            if ($category) {
                $cat_name = $cat_name . $category[0]->name;
            }

            if ($tags) {
                foreach ($tags as $tag) {
                    $tag_names = $tag_names . $tag->name;
                    $tag_names = $tag_names . ',';
                }
            }

            $post_data = array(
                // "active" => false,                
                "articleIdentifier" => $article_identifier,
                "author" => $author_name,
                "category" => $cat_name,
                "contentType" => "text",
                "description" => substr($post_desc, 0, 60),
                "headline" => $post->post_title,
                "imageHeight" => 0,
                "imageUrl" => get_the_post_thumbnail_url($post->ID) ?? "",
                "imageWidth" => 0,
                "monetizeType" => "paywall",
                // "originalUrl" => get_post_permalink($post->ID),
                "originalUrl" => get_permalink($post->ID),
                // "originalUrl" => "https://absdkfjk.asdf/sad/asdf".rand(0,1000),
                "price" => 0,
                "publishedDate" =>  $publish_date->format(DateTime::ATOM),
                "tags" => $tag_names,
                "title" =>  $post->post_title
                // "active" => 1
            );

            array_push($data, $post_data);
        }

        echo json_encode($data);
    } catch (Throwable $e) {
        echo json_encode($e->getMessage());
    }
}

function fcpt_validate_access_key($value)
{
    if (empty($value)) {
        throw new Exception("Access Key cannot be empty!");
    }
}

function fcpt_validate_logo_url($value)
{
    if (empty($value)) {
        throw new Exception("Logo Url cannot be empty!");
    }
}

function fcpt_validate_source_url($value)
{
    if (empty($value)) {
        throw new Exception("Paywall Source Url cannot be empty!");
    }
}

function fcpt_validate_content_selector($value)
{
    if (empty($value)) {
        throw new Exception("Content Selector cannot be empty!");
    }
}

function fcpt_validate_header_url($value)
{
    if (empty($value)) {
        throw new Exception("Header Url cannot be empty!");
    }
}

function fcpt_lite_plugin_request()
{
    $access_key =  sanitize_text_field($_REQUEST['access_key']);
    $logo_url = esc_url_raw($_REQUEST['logo_url']);
    $content_selector = sanitize_text_field($_REQUEST['content_selector']);
    $primary_color = sanitize_hex_color($_REQUEST['primary_color']);
    $paywall_source_url = esc_url_raw($_REQUEST['paywall_source_url']);
    $monetize_type = sanitize_text_field($_REQUEST['monetize_type']);
    $content_preview_height = sanitize_text_field($_REQUEST['content_preview_height']);
    $bubble_position = sanitize_text_field($_REQUEST['bubble_position']);
    $mobile_offset_vertical = sanitize_text_field($_REQUEST['mobile_offset_vertical']);
    $mobile_offset_horizontal = sanitize_text_field($_REQUEST['mobile_offset_horizontal']);
    $desktop_offset_vertical = sanitize_text_field($_REQUEST['desktop_offset_vertical']);
    $desktop_offset_horizontal = sanitize_text_field($_REQUEST['desktop_offset_horizontal']);
    $infinite_scroll = rest_sanitize_boolean($_REQUEST['infinite_scroll']);
    $borderless = rest_sanitize_boolean($_REQUEST['borderless']);
    $function_selector = sanitize_text_field($_REQUEST['function_selector']);
    $event_handlers = sanitize_text_field($_REQUEST['event_handlers']);
    $should_inject_paywall = sanitize_text_field($_REQUEST['should_inject_paywall']);


    fcpt_validate_access_key($access_key);
    fcpt_validate_content_selector($content_selector);
    fcpt_validate_logo_url($logo_url);
    fcpt_validate_source_url($paywall_source_url);

    update_option('should_inject_paywall',  $should_inject_paywall);
    update_option('event_handlers',  $event_handlers);
    update_option('function_selector', $function_selector);
    update_option('access_key', $access_key);
    update_option('logo_url', $logo_url);
    update_option('content_selector', $content_selector);
    update_option('primary_color', $primary_color);
    update_option('bubble_position', $bubble_position);
    update_option('paywall_source_url', $paywall_source_url);
    update_option('monetize_type', $monetize_type);
    update_option('content_preview_height', $content_preview_height);
    update_option('mobile_offset_vertical', $mobile_offset_vertical);
    update_option('mobile_offset_horizontal', $mobile_offset_horizontal);
    update_option('desktop_offset_vertical', $desktop_offset_vertical);
    update_option('desktop_offset_horizontal', $desktop_offset_horizontal);
    update_option('infinite_scroll', $infinite_scroll);
    update_option('borderless', $borderless);
}


function fcpt_process_post_request()
{
    try {
        if (isset($_POST)) {
            $request_for = sanitize_text_field($_REQUEST['requestFor']);

            switch ($request_for) {
                case 'inject_script_lite':
                    fcpt_lite_plugin_request($_REQUEST);
                    break;
                case 'inject_script':
                    $header_url = esc_url_raw($_REQUEST['header_url']);
                    $access_key = sanitize_text_field($_REQUEST['access_key']);
                    $logo_url = esc_url_raw($_REQUEST['logo_url']);

                    fcpt_validate_header_url($header_url);
                    fcpt_validate_access_key($access_key);
                    fcpt_validate_logo_url($logo_url);

                    update_option('header_url', $header_url);
                    update_option('access_key', $access_key);
                    update_option('logo_url', $logo_url);
                    break;
                case 'retrieve_posts':
                    fcpt_get_posts();
                    break;
                default:
                    echo json_encode("request failed");
            }
        }
    } finally {
        die();
    }
}
